/* ============================================================
 *
 * This file is a part of educazionik project
 * http://educazionik.sourceforge.net/
 *
 * Date        : 25/11/2009
 * Description : lessico
 *
 * Copyright 2003-2009 by Nicola De Filippo <nicola@nicoladefilippo.it>
 * Copyright 2009      by Angelo Naselli    <anaselli at linux dot it>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include<qmessagebox.h>
#include <qapplication.h>
#include <QIcon>
#include "form1.h"
#include "form2.h"
#include "form3.h"
#include "form4.h"
#include "form5.h"
#include "form6.h"
#include "form7.h"
#include "form8.h"
#include "form9.h"
#include "form10.h"
#include "ui_form1.h"
#include "aboutdlg.h"
#include "lessico_version.h"

struct privateForm
{
    Form2*  formAbbinaContrari;
    Form3*  formAbbinaSinonimi;
    Form4*  formAbbinaGradi;
    Form5*  formSinonimiContrari;
    Form6*  formParolaCorretta;
    Form7*  formLessico;
    Form8*  formGradi;
    Form9*  formParolaComprende;
    Form10* formParolaIntrusa;
    QString title;

    privateForm() : formAbbinaContrari(NULL), formAbbinaSinonimi(NULL),
                    formAbbinaGradi(NULL), formSinonimiContrari(NULL),
                    formParolaCorretta(NULL), formLessico(NULL),
                    formGradi(NULL), formParolaComprende(NULL),
                    formParolaIntrusa(NULL)
    {}
    ~privateForm()
    {
      delete(formAbbinaContrari);
      delete(formAbbinaSinonimi);
      delete(formAbbinaGradi);
      delete(formSinonimiContrari);
      delete(formParolaCorretta);
      delete(formLessico);
      delete(formGradi);
      delete(formParolaComprende);
      delete(formParolaIntrusa);

    }
};

Form1::Form1(QWidget *parent)
        : QDialog(parent), ui(new Ui::Form1), d(new privateForm)
{
    ui->setupUi(this);
    init();
}

Form1::~Form1()
{
    delete ui;
    delete d;
}


void Form1::init()
{
   d->title = QString(APPL_NAME)    + " V. " +
              QString(APPL_VERSION) + " ";
  setWindowIcon(QIcon( QPixmap(QString(RESOURCE_DIR) + "/educazionik.png")));

  d->formAbbinaContrari = new Form2(this);
  d->formAbbinaSinonimi = new Form3(this);
  d->formAbbinaGradi = new Form4(this);
  d->formSinonimiContrari = new Form5(this);
  d->formParolaCorretta = new Form6(this);
  d->formLessico = new Form7(this);
  d->formGradi = new Form8(this);
  d->formParolaComprende = new Form9(this);
  d->formParolaIntrusa = new Form10(this);
  setWindowTitle(d->title);

  connect(d->formAbbinaContrari, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
  connect(d->formAbbinaSinonimi, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
  connect(d->formAbbinaGradi, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
  connect(d->formParolaCorretta, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
  connect(d->formSinonimiContrari, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
  connect(d->formLessico, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
  connect(d->formGradi, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
  connect(d->formParolaComprende, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
  connect(d->formParolaIntrusa, SIGNAL(accepted()), this, SLOT(manage_dialog_end()));
}
void Form1::blockButtonSignals(bool block)
{
  ui->pushButton1->blockSignals(block);
  ui->pushButton2->blockSignals(block);
  ui->pushButton3->blockSignals(block);
  ui->pushButton4->blockSignals(block);
  ui->pushButton5->blockSignals(block);
  ui->pushButton6->blockSignals(block);
  ui->pushButton7->blockSignals(block);
  ui->pushButton8->blockSignals(block);
  ui->pushButton9->blockSignals(block);
}

void Form1::manage_dialog_end()
{
  this->show();
  blockButtonSignals(false);
}

void Form1::abbina_c()
{
  blockButtonSignals();
  this->hide();
  d->formAbbinaContrari->init();
  d->formAbbinaContrari->exec();
}

void Form1::abbina_s()
{
  blockButtonSignals();
  this->hide();
  d->formAbbinaSinonimi->init();
  d->formAbbinaSinonimi->exec();
}

void Form1::abbina_g()
{
  blockButtonSignals();
  this->hide();
  d->formAbbinaGradi->init();
  d->formAbbinaGradi->exec();  
}

void Form1::corretta()
{
  blockButtonSignals();
  this->hide();
  d->formParolaCorretta->init();
  d->formParolaCorretta->exec();
}

void Form1::sinonimi_c()
{
  blockButtonSignals();
  this->hide();
  d->formSinonimiContrari->init();
  d->formSinonimiContrari->exec();
}

void Form1::lessico()
{
  blockButtonSignals();
  this->hide();

  d->formLessico->init();
  d->formLessico->exec();
}

void Form1::gradi()
{
  blockButtonSignals();
  this->hide();

  d->formGradi->init();
  d->formGradi->exec();
}

void Form1::comprende()
{
  blockButtonSignals();
  this->hide();

  d->formParolaComprende->init();
  d->formParolaComprende->exec();
}

void Form1::intrusa()
{
  blockButtonSignals();
  this->hide();

  d->formParolaIntrusa->init();
  d->formParolaIntrusa->exec();
}

void Form1::esci()
{
  QApplication::exit();
}

void Form1::info()
{
  QString info = "(c) 2003 <b>Nicola De Filippo</b> - nicola@nicoladefilippo.it<br>"
                 "(c) 2009 <b>Angelo Naselli</b>    - anaselli@linux.it<br>";
  info += "http://educazionik.sourceforge.net";
  QString description = "Programma per esercitazioni di lessico";
  QString icon = QString(RESOURCE_DIR) + "/logo.png";

  //AboutDialog about(this, d->title, info, description, icon);
  AboutDialog about(this, d->title, "", description, icon, "", "", "");
  about.exec();
}
