/* ============================================================
 *
 * This file is a part of educazionik project
 * http://educazionik.sourceforge.net/
 *
 * Date        : 13-8-2002
 * Description : Lessico implementation
 *
 * Copyright 2002-2009 by Nicola De Filippo <nicola@nicoladefilippo.it>
 * Copyright 2009      by Angelo Naselli    <anaselli at linux dot it>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include<qmessagebox.h>
#include "form4.h"
#include "ui_form2.h"
#include "accoppiamenti.h"
#include "lessico_version.h"

struct privateForm4
{
    accoppiamenti *coppie;
    int indovinati;
    QString title;
    QString filename;
    
    privateForm4() : coppie(NULL) {}
    ~privateForm4()
    {
      if (coppie)
        delete coppie;
    }
};

Form4::Form4(QWidget *parent)
        : QDialog(parent), ui(new Ui::Form2), d(new privateForm4)
{
  ui->setupUi(this);
  d->title = QString(APPL_NAME)    + " V. " +
              QString(APPL_VERSION) + " "    +
              QString(APPL_DATE)    + " "    +
              QString(APPL_TIME);
  d->filename = QString(DATA_DIR) + "/gradi.txt";

  setWindowTitle("Abbina gradi");
  connect(ui->lineEdit2, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit4, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit6, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit8, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit10, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit12, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit14, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit16, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));
  connect(ui->lineEdit18, SIGNAL(dropReceived(QLabel *, QLabel *)), this, SLOT(action_drop(QLabel*,QLabel*)));

  connect(ui->m_resultTable->m_exit, SIGNAL(pressed()), this, SLOT(esci()));
  connect(ui->m_resultTable->m_go_on, SIGNAL(pressed()), this, SLOT(avanti()));
  connect(ui->m_resultTable->m_resetButton, SIGNAL(pressed()), this, SLOT(azzera()));
}

Form4::~Form4()
{
    delete ui;
    delete d;
}

void Form4::init()
{
    QString a[9],b[9];
    
    if (!d->coppie)
      d->coppie=new accoppiamenti(d->filename,9);
    if (d->coppie->errore()!=-1)
    {
        d->coppie->frase(&a[0],&b[0]);

        ui->lineEdit1->setText(a[0]);
        ui->lineEdit3->setText(a[1]);
        ui->lineEdit5->setText(a[2]);
        ui->lineEdit7->setText(a[3]);
        ui->lineEdit9->setText(a[4]);
        ui->lineEdit11->setText(a[5]);
        ui->lineEdit13->setText(a[6]);
        ui->lineEdit15->setText(a[7]);
        ui->lineEdit17->setText(a[8]);

        ui->lineEdit1->setDragging(true);
        ui->lineEdit3->setDragging(true);
        ui->lineEdit5->setDragging(true);
        ui->lineEdit7->setDragging(true);
        ui->lineEdit9->setDragging(true);
        ui->lineEdit11->setDragging(true);
        ui->lineEdit13->setDragging(true);
        ui->lineEdit15->setDragging(true);
        ui->lineEdit17->setDragging(true);


        ui->lineEdit2->setText(b[0]);
        ui->lineEdit4->setText(b[1]);
        ui->lineEdit6->setText(b[2]);
        ui->lineEdit8->setText(b[3]);
        ui->lineEdit10->setText(b[4]);
        ui->lineEdit12->setText(b[5]);
        ui->lineEdit14->setText(b[6]);
        ui->lineEdit16->setText(b[7]);
        ui->lineEdit18->setText(b[8]);

        ui->m_resultTable->m_go_on->setEnabled(false);

        d->indovinati=0;
    }
    else
    {
        ui->lineEdit1->hide();
        ui->lineEdit2->hide();
        ui->lineEdit3->hide();
        ui->lineEdit4->hide();
        ui->lineEdit5->hide();
        ui->lineEdit6->hide();
        ui->lineEdit7->hide();
        ui->lineEdit8->hide();
        ui->lineEdit9->hide();
        ui->lineEdit10->hide();
        ui->lineEdit11->hide();
        ui->lineEdit12->hide();
        ui->lineEdit13->hide();
        ui->lineEdit14->hide();
        ui->lineEdit15->hide();
        ui->lineEdit16->hide();
        ui->lineEdit17->hide();
        ui->lineEdit18->hide();

        ui->m_resultTable->LCD_Wrong->hide();
        ui->m_resultTable->LCD_Correct->hide();
 
        QMessageBox::critical( 0, d->title, QString("Non riesco a trovare il file ") + d->filename);
        // Diamo la possibilità di ricaricare il file se non trovato
        delete d->coppie;
        d->coppie = NULL;
    }
    d->indovinati=0;
}




void Form4::azzera()
{
    ui->m_resultTable->LCD_Wrong->display(0);
    ui->m_resultTable->LCD_Correct->display(0);
}

void Form4::avanti()
{
    QString a[9],b[9];

    d->coppie->frase(&a[0],&b[0]);

    ui->lineEdit1->setText(a[0]);
    ui->lineEdit3->setText(a[1]);
    ui->lineEdit5->setText(a[2]);
    ui->lineEdit7->setText(a[3]);
    ui->lineEdit9->setText(a[4]);
    ui->lineEdit11->setText(a[5]);
    ui->lineEdit13->setText(a[6]);
    ui->lineEdit15->setText(a[7]);
    ui->lineEdit17->setText(a[8]);

    ui->lineEdit2->setText(b[0]);
    ui->lineEdit4->setText(b[1]);
    ui->lineEdit6->setText(b[2]);
    ui->lineEdit8->setText(b[3]);
    ui->lineEdit10->setText(b[4]);
    ui->lineEdit12->setText(b[5]);
    ui->lineEdit14->setText(b[6]);
    ui->lineEdit16->setText(b[7]);
    ui->lineEdit18->setText(b[8]);

    ui->m_resultTable->m_go_on->setEnabled(false);

    ui->lineEdit1->setEnabled(true);
    ui->lineEdit2->setEnabled(true);
    ui->lineEdit3->setEnabled(true);
    ui->lineEdit4->setEnabled(true);
    ui->lineEdit5->setEnabled(true);
    ui->lineEdit6->setEnabled(true);
    ui->lineEdit7->setEnabled(true);
    ui->lineEdit8->setEnabled(true);
    ui->lineEdit9->setEnabled(true);
    ui->lineEdit10->setEnabled(true);
    ui->lineEdit11->setEnabled(true);
    ui->lineEdit12->setEnabled(true);
    ui->lineEdit13->setEnabled(true);
    ui->lineEdit14->setEnabled(true);
    ui->lineEdit15->setEnabled(true);
    ui->lineEdit15->setEnabled(true);
    ui->lineEdit16->setEnabled(true);
    ui->lineEdit17->setEnabled(true);
    ui->lineEdit18->setEnabled(true);
    d->indovinati=0;
}

void Form4::esci()
{
    ui->lineEdit1->setEnabled(true);
    ui->lineEdit2->setEnabled(true);
    ui->lineEdit3->setEnabled(true);
    ui->lineEdit4->setEnabled(true);
    ui->lineEdit5->setEnabled(true);
    ui->lineEdit6->setEnabled(true);
    ui->lineEdit7->setEnabled(true);
    ui->lineEdit8->setEnabled(true);
    ui->lineEdit9->setEnabled(true);
    ui->lineEdit10->setEnabled(true);
    ui->lineEdit11->setEnabled(true);
    ui->lineEdit12->setEnabled(true);
    ui->lineEdit13->setEnabled(true);
    ui->lineEdit14->setEnabled(true);
    ui->lineEdit15->setEnabled(true);
    ui->lineEdit15->setEnabled(true);
    ui->lineEdit16->setEnabled(true);
    ui->lineEdit17->setEnabled(true);
    ui->lineEdit18->setEnabled(true);
    d->indovinati=0;
    ui->m_resultTable->LCD_Wrong->display(0);
    ui->m_resultTable->LCD_Correct->display(0);
    this->accept();
}

void Form4::action_drop( QLabel *a, QLabel *b )
{
    QString sum;

    if ((d->coppie->esatto(a->text(),b->text()))>-1)
    {
        sum=a->text()+"/ "+b->text();
        b->setText(sum);
        ui->m_resultTable->LCD_Correct->display(ui->m_resultTable->LCD_Correct->intValue()+1);
        if (++d->indovinati ==9)
            ui->m_resultTable->m_go_on->setEnabled(true);
        a->setEnabled(false);
        b->setEnabled(false);
    }
    else
    {
        ui->m_resultTable->LCD_Wrong->display(ui->m_resultTable->LCD_Wrong->intValue()+1);
    }
}
